@@ -1,7 +1,7 @@
 """
 Type annotations for ce service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/literals/)
 
 Usage::
 
@@ -52,7 +52,9 @@ __all__ = (
     "SubscriberTypeType",
     "SupportedSavingsPlansTypeType",
     "TermInYearsType",
+    "CostExplorerServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
@@ -163,6 +165,7 @@ SubscriberStatusType = Literal["CONFIRMED", "DECLINED"]
 SubscriberTypeType = Literal["EMAIL", "SNS"]
 SupportedSavingsPlansTypeType = Literal["COMPUTE_SP", "EC2_INSTANCE_SP", "SAGEMAKER_SP"]
 TermInYearsType = Literal["ONE_YEAR", "THREE_YEARS"]
+CostExplorerServiceName = Literal["ce"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -194,11 +197,13 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -280,6 +285,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -313,9 +319,11 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -380,6 +388,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -464,3 +473,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
