@@ -1,7 +1,7 @@
 """
 Type annotations for ce service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ce/type_defs/)
 
 Usage::
 
@@ -142,6 +142,8 @@ __all__ = (
     "InstanceDetailsTypeDef",
     "ListCostCategoryDefinitionsRequestRequestTypeDef",
     "ListCostCategoryDefinitionsResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "MetricValueTypeDef",
     "ModifyRecommendationDetailTypeDef",
     "NetworkResourceUtilizationTypeDef",
@@ -157,6 +159,7 @@ __all__ = (
     "ReservationPurchaseRecommendationTypeDef",
     "ReservationUtilizationGroupTypeDef",
     "ResourceDetailsTypeDef",
+    "ResourceTagTypeDef",
     "ResourceUtilizationTypeDef",
     "ResponseMetadataTypeDef",
     "ResultByTimeTypeDef",
@@ -181,10 +184,12 @@ __all__ = (
     "ServiceSpecificationTypeDef",
     "SortDefinitionTypeDef",
     "SubscriberTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagValuesTypeDef",
     "TargetInstanceTypeDef",
     "TerminateRecommendationDetailTypeDef",
     "TotalImpactFilterTypeDef",
+    "UntagResourceRequestRequestTypeDef",
     "UpdateAnomalyMonitorRequestRequestTypeDef",
     "UpdateAnomalyMonitorResponseTypeDef",
     "UpdateAnomalySubscriptionRequestRequestTypeDef",
@@ -462,12 +467,27 @@ CoverageTypeDef = TypedDict(
     total=False,
 )
 
-CreateAnomalyMonitorRequestRequestTypeDef = TypedDict(
-    "CreateAnomalyMonitorRequestRequestTypeDef",
+_RequiredCreateAnomalyMonitorRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAnomalyMonitorRequestRequestTypeDef",
     {
         "AnomalyMonitor": "AnomalyMonitorTypeDef",
     },
 )
+_OptionalCreateAnomalyMonitorRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAnomalyMonitorRequestRequestTypeDef",
+    {
+        "ResourceTags": Sequence["ResourceTagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateAnomalyMonitorRequestRequestTypeDef(
+    _RequiredCreateAnomalyMonitorRequestRequestTypeDef,
+    _OptionalCreateAnomalyMonitorRequestRequestTypeDef,
+):
+    pass
+
 
 CreateAnomalyMonitorResponseTypeDef = TypedDict(
     "CreateAnomalyMonitorResponseTypeDef",
@@ -477,12 +497,27 @@ CreateAnomalyMonitorResponseTypeDef = TypedDict(
     },
 )
 
-CreateAnomalySubscriptionRequestRequestTypeDef = TypedDict(
-    "CreateAnomalySubscriptionRequestRequestTypeDef",
+_RequiredCreateAnomalySubscriptionRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAnomalySubscriptionRequestRequestTypeDef",
     {
         "AnomalySubscription": "AnomalySubscriptionTypeDef",
     },
 )
+_OptionalCreateAnomalySubscriptionRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAnomalySubscriptionRequestRequestTypeDef",
+    {
+        "ResourceTags": Sequence["ResourceTagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateAnomalySubscriptionRequestRequestTypeDef(
+    _RequiredCreateAnomalySubscriptionRequestRequestTypeDef,
+    _OptionalCreateAnomalySubscriptionRequestRequestTypeDef,
+):
+    pass
+
 
 CreateAnomalySubscriptionResponseTypeDef = TypedDict(
     "CreateAnomalySubscriptionResponseTypeDef",
@@ -505,6 +540,7 @@ _OptionalCreateCostCategoryDefinitionRequestRequestTypeDef = TypedDict(
     {
         "DefaultValue": str,
         "SplitChargeRules": Sequence["CostCategorySplitChargeRuleTypeDef"],
+        "ResourceTags": Sequence["ResourceTagTypeDef"],
     },
     total=False,
 )
@@ -1445,6 +1481,21 @@ ListCostCategoryDefinitionsResponseTypeDef = TypedDict(
     },
 )
 
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "ResourceTags": List["ResourceTagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 MetricValueTypeDef = TypedDict(
     "MetricValueTypeDef",
     {
@@ -1628,6 +1679,14 @@ ResourceDetailsTypeDef = TypedDict(
     total=False,
 )
 
+ResourceTagTypeDef = TypedDict(
+    "ResourceTagTypeDef",
+    {
+        "Key": str,
+        "Value": str,
+    },
+)
+
 ResourceUtilizationTypeDef = TypedDict(
     "ResourceUtilizationTypeDef",
     {
@@ -1815,7 +1874,9 @@ SavingsPlansPurchaseRecommendationTypeDef = TypedDict(
         "SavingsPlansPurchaseRecommendationDetails": List[
             "SavingsPlansPurchaseRecommendationDetailTypeDef"
         ],
-        "SavingsPlansPurchaseRecommendationSummary": "SavingsPlansPurchaseRecommendationSummaryTypeDef",
+        "SavingsPlansPurchaseRecommendationSummary": (
+            "SavingsPlansPurchaseRecommendationSummaryTypeDef"
+        ),
     },
     total=False,
 )
@@ -1935,6 +1996,14 @@ SubscriberTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "ResourceTags": Sequence["ResourceTagTypeDef"],
+    },
+)
+
 TagValuesTypeDef = TypedDict(
     "TagValuesTypeDef",
     {
@@ -1990,6 +2059,14 @@ class TotalImpactFilterTypeDef(
     pass
 
 
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "ResourceTagKeys": Sequence[str],
+    },
+)
+
 _RequiredUpdateAnomalyMonitorRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateAnomalyMonitorRequestRequestTypeDef",
     {
